@@ -1,7 +1,6 @@
-#!/usr/bin/python
 #-*- coding: utf-8 -*-
 
-# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -39,7 +38,6 @@ class CommonInfo(ClassSerializer):
     cl_verbose_set = Boolean
 
     Default = Array(String)
-    CheckOnly = Boolean
     CheckAll = Boolean
 
 class DataVarsSerializer(ClassSerializer):
@@ -215,7 +213,7 @@ class Field(DataVarsSerializer):
             self.help = varObj.help
             self.element = varObj.element or \
                            self.elementByType(self.type)
-            if not onlyhelp or varObj.syntax:
+            if not onlyhelp or varObj.syntax or self.type == "table":
                 self.label = varObj.label or varObj.name
                 if inbrief:
                     self.uncompatible = ""
@@ -361,7 +359,7 @@ class ViewInfo(DataVarsSerializer):
             varGroups = datavars.getGroups()
             lastGroup = len(varGroups)-1
             # interate all vars group
-            if not onlyhelp and (step in(0,-1,None) or allsteps):
+            if step in(0,-1,None) or allsteps:
                 briefData = datavars.getBrief()
                 self.groups.append(self.stepGroup(varGroups,brief_label,
                             help_value=briefData.get("help",None),
@@ -372,6 +370,12 @@ class ViewInfo(DataVarsSerializer):
                     self.groups.append(GroupField(dv=datavars,info=groupInfo,
                                          last=(lastGroup==i),expert=expert,
                                          brief=brief,onlyhelp=onlyhelp))
+                    if groupInfo['custom_buttons']:
+                        for but in groupInfo['custom_buttons']:
+                            self.groups[-1].fields.append(Field(
+                                name=but[0],label=but[1],value=but[2],
+                                element=but[3]))
+
         else:
             self.groups = groups
 
@@ -424,11 +428,16 @@ class Message(ClassSerializer):
     type = String
     message = String
     id = Integer
+    result = Boolean
+    onlyShow = String
 
-    def __init__(self, type = 'normal', message = None, id = None):
+    def __init__(self, type = 'normal', message = None, id = None,
+                 result = None, onlyShow = None):
         self.type = type
         self.message = message
         self.id = id
+        self.result = result
+        self.onlyShow = onlyShow
 
 class ReturnProgress(ClassSerializer):
     percent = Integer
@@ -489,6 +498,76 @@ class CoreWsdl:
                 self.set_cache(sid,method_name,"vars",dv,smart=False)
         return []
 
+    def callAction(self,sid,info,logicClass={},
+                   method_name=None,
+                   actionClass=None,
+                   callbackRefresh=lambda sid,dv:True):
+        """
+        Общий алгоритм вызова действия
+        """
+        try:
+            dv = self.get_cache(sid,method_name,"vars")
+            if not dv:
+                dv = getattr(self,"%s_vars"%method_name)()
+            else:
+                callbackRefresh(sid,dv)
+                dv.processRefresh()
+            checkonly = False
+            checkall = False
+            if info and hasattr(info,"CheckOnly"):
+                checkonly = info.CheckOnly
+            if info and not hasattr(info,"CheckOnly"):
+                checkall = True
+            elif info and hasattr(info,"CheckAll"):
+                checkall = info.CheckAll
+            errors = map(lambda x:ReturnedMessage(**x),
+                     dv.checkGroups(info,allvars=checkall or not checkonly))
+            if errors:
+                return errors
+            if checkonly:
+                returnmess = ReturnedMessage(type = '', message = None)
+                return [returnmess]
+            if not actionClass:
+                return []
+            objs = {}
+            from calculate.core.server.func import CommonLink
+            for k,v in logicClass.items():
+                objs[k] = type("Logic",(CommonLink, v, object), {})()
+            install_meth = type("CommonCore",(self.Common,
+                                actionClass, object), {})
+            pid = self.startprocess(sid, target=install_meth,
+                            method="run",
+                            method_name=method_name,
+                            args_proc = (objs,dv,))
+            returnmess = ReturnedMessage(type = 'pid', message = pid)
+            returnmess.type = "pid"
+            returnmess.message = pid
+            self.clear_cache(sid,method_name)
+            dv = None
+            return [returnmess]
+        finally:
+            if dv:
+                self.set_cache(sid,method_name,"vars",dv,smart=False)
+        return []
+
+    def fixInstallLocalization(self,sid,dv):
+        """
+        Метод смены локализации интерфейса на лету (во время выбора
+        параметров метода)
+        """
+        if not "--start" in sys.argv:
+            return False
+        import threading
+        curThread = threading.currentThread()
+        curThread.lang = dv.Get('install.os_install_locale_lang')
+        currentLang = self.get_cache(sid,"install","lang")
+        if currentLang != curThread.lang:
+            dv.clearGroups()
+            self.install_vars(dv)
+            dv.reinit()
+            return True
+        else:
+            return False
 
     # verification of compliance certificate and process (pid)
     def check_cert_pid (self, sid, pid):
@@ -536,20 +615,22 @@ class CoreWsdl:
         return 0
 
     # send to client all new message
-    def process_messages (self, pid):
+    def process_messages (self, pid,client_type):
         result = []
         while len(self.glob_frame_list[pid]) > \
                   self.glob_process_dict[pid]['counter']:
-
             item = self.glob_process_dict[pid]['counter']
-            result.append(self.glob_frame_list[pid][item])
+            onlyShow = self.glob_frame_list[pid][item].onlyShow
+            if not client_type or \
+                not onlyShow or onlyShow == client_type:
+                result.append(self.glob_frame_list[pid][item])
             self.glob_process_dict[pid]['counter'] += 1
         return result
 
     # send to client new message from frame
-    def client_get_frame(self, sid, pid):
+    def client_get_frame(self, sid, pid, client_type):
         if self.check_cert_pid(sid, pid):
-            return self.process_messages(pid)
+            return self.process_messages(pid,client_type)
         return self.perm_denied
 
     # send to client new message from frame
@@ -581,10 +662,10 @@ class CoreWsdl:
             return Message (type = 'normal', message = "")
         return self.perm_denied
 
-    @rpc(Integer, Integer, _returns = Array(Message))
+    @rpc(Integer, Integer, String, _returns = Array(Message))
     #@Dec.check_permissions()
-    def get_frame (self, sid, pid):
-        return self.client_get_frame (sid, pid)
+    def get_frame (self, sid, pid, client_type):
+        return self.client_get_frame (sid, pid, client_type)
 
     @rpc(Integer, Integer, _returns = Array(Message))
     def get_entire_frame(self, sid, pid):
