@@ -552,7 +552,7 @@ class Action:
             raise ActionError(_("Object %s not found")%objname)
         obj = objs[objname]
         if not hasattr(obj,methodname):
-            raise ActionError(_("Method {method} for {obj} in not found").
+            raise ActionError(_("Method {method} for {obj} not found").
                         format(method=methodname,obj=objname))
 
         def _convertMethodArg(param):
@@ -725,7 +725,7 @@ class Action:
                 except KeyboardInterrupt as e:
                     if action.get("essential",True):
                         result[name]=False
-                    self.printWARNING(_("Task was interrupted"))
+                    self.printWARNING(_("Task interrupted"))
                     result["interrupt"] = False
                 except self.native_error as e:
                     self.printERROR(str(e))
@@ -1659,7 +1659,7 @@ class WsdlBase:
 def clearDataVars(func):
     def wrapper(*args,**kwargs):
         try:
-            func(*args,**kwargs)
+            return func(*args,**kwargs)
         finally:
             WsdlMeta.closeDataVars()
     return wrapper
