@@ -1,7 +1,6 @@
-#!/usr/bin/python
 #-*- coding: utf-8 -*-
 
-# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -26,8 +25,8 @@ from cert_cmd import parse
 import sys, termios
 import os
 import re
-from methods_func import getErrorOnParam
-from func import shortTraceback,CommonMethods
+from methods_func import getErrorOnParam,GotErrorField
+from func import shortTraceback, CommonMethods
 from fcntl import ioctl
 from array import array
 import threading
@@ -69,6 +68,7 @@ class replaceClass():
             self.error = []
             self.warning = []
             self.no_questions = no_questions
+            self.currentTaskMessage = ""
 
         def writeFile(self):
             pass
@@ -150,7 +150,8 @@ class replaceClass():
                     return self.progressbar.currval
             return 100
 
-        def addProgress(self,message):
+        def addProgress(self,message=""):
+            self.nextLine()
             if self.no_progress:
                 self.progress = 0
                 return
@@ -180,14 +181,19 @@ class replaceClass():
             self.printSUCCESS(message = table_name)
             print printTable(body, head)
 
-        def addMessage(self, type = 'normal', message = None, id = None):
-            self.printSUCCESS(message)
+        def addMessage(self, type = 'normal', message = None, id = None,
+                       onlyShow = None):
+            self.printSUCCESS(message, onlyShow = onlyShow)
 
-        def printDefault(self,message = ''):
+        def printDefault(self,message = '', onlyShow = None):
+            if onlyShow == "gui":
+                return
             message = self.clearTags(message)
             self.color_print.defaultPrint(message+"\n")
 
-        def printPre(self,message = ''):
+        def printPre(self,message = '', onlyShow = None):
+            if onlyShow == "gui":
+                return
             for line in message.split('<br/>'):
                 self.printDefault(line)
 
@@ -223,8 +229,11 @@ class replaceClass():
                 "",reFont.sub(fontFunc,s)).replace("&nbsp;"," ")
             #return self.reClearTags.sub("",s)
 
-        def printSUCCESS(self, message = '', type = None, id = None):
+        def printSUCCESS(self, message = '', onlyShow = None):
+            if onlyShow == "gui":
+                return
             if message:
+                self.nextLine()
                 if self.progressbar and not self.gui_progress:
                     if not self.progressbar.finished:
                         cout_progress()
@@ -234,7 +243,10 @@ class replaceClass():
                 for line in message.splitlines():
                     self.color_print.printSUCCESS(self.clearTags(line))
 
-        def printWARNING(self, message):
+        def printWARNING(self, message = '', onlyShow = None):
+            if onlyShow == "gui":
+                return
+            self.nextLine()
             if self.progressbar and not self.no_progress \
                     and not self.gui_progress:
                 if not self.progressbar.finished:
@@ -250,7 +262,10 @@ class replaceClass():
             if message:
                 self.warning.append(message)
 
-        def printERROR(self, message = ''):
+        def printERROR(self, message = '', onlyShow = None):
+            if onlyShow == "gui":
+                return
+            self.nextLine()
             perc = self.getProgress()
             if perc == 0:
                 self.setProgress(100)
@@ -268,7 +283,11 @@ class replaceClass():
                 self.error.append(message)
 
         def startTask(self, message, progress = False, num = 1):
-            self.printSUCCESS(message = message)
+            self.nextLine()
+            message = self.clearTags(message)
+            self.color_print.printSUCCESS(message,printBR=False)
+            self.color_print.defaultPrint(" ...")
+            self.currentTaskMessage = message
             if progress:
                 self.addProgress(message)
 
@@ -276,15 +295,30 @@ class replaceClass():
             pass
 
         def endTask(self, result = None, progress_message = None):
-            if result:
+            if result and not result is True:
                 self.color_print.printOK(self.clearTags(result))
+            elif self.currentTaskMessage:
+                if not result is False:
+                    self.color_print.printOnlyOK("",
+                        len(unicode(self.currentTaskMessage))+8)
+                    self.currentTaskMessage = ""
+                if result is False:
+                    self.color_print.printOnlyNotOK("",
+                        len(unicode(self.currentTaskMessage))+8)
+                    self.currentTaskMessage = ""
+            self.nextLine()
             self.setProgress(100, progress_message)
 
+        def nextLine(self):
+            if self.currentTaskMessage:
+                self.color_print.defaultPrint('\n')
+                self.currentTaskMessage = ""
+
         def askConfirm(self,message,default="yes"):
             colorPrint = color_print()
-            print
             if self.no_questions:
                 return default
+            print
             while True:
                 try:
                     ask = raw_input(message+ ' (yes/no): ')
@@ -332,7 +366,7 @@ class replaceClass():
                 ask = ask.lower()
                 likeAnswers = filter(lambda x:x[VALUE].startswith(ask),answers)
                 if not likeAnswers:
-                    colorPrint.printERROR(_('The answer is not understood'))
+                    colorPrint.printERROR(_('The answer is uncertain'))
                     continue
                 if len(likeAnswers) == 1:
                     return likeAnswers[VALUE][FIRSTLETTER]
@@ -370,7 +404,7 @@ class replaceClass():
             self.printSUCCESS(message = message)
 
         def endFrame(self):
-            self.printSUCCESS(type = 'endFrame')
+            self.addMessage(type = 'endFrame')
             if self.gui_progress and self.progressbar:
                 self.progressbar.quit()
             if self.warning and not self.error and self.gui_warning:
@@ -383,12 +417,9 @@ class replaceClass():
                 ClMessageBox().critical(error.decode('utf-8'))
 
         def startGroup(self, message):
-            self.printSUCCESS(type = 'startGroup', message = message)
+            self.addMessage(type = 'startGroup', message = message)
 
-        def endGruop(self):
-            pass
-
-        def briefParams(self, view_name):
+        def endGroup(self):
             pass
 
 def cout_progress(string = None):
@@ -444,10 +475,10 @@ def local_method(metaclass, args, unknown_args):
         try:
             method_parser = get_method_argparser(view, args, cl_core = True)
         except Exception as e:
-            import traceback
-            for i in apply(traceback.format_exception, sys.exc_info()):
-                sys.stderr.write(i)
-            sys.stderr.flush()
+            #import traceback
+            #for i in apply(traceback.format_exception, sys.exc_info()):
+            #    sys.stderr.write(i)
+            #sys.stderr.flush()
             metaObject.clear_cache(0, method_name)
             return  1
         method_parser.print_help()
@@ -461,6 +492,8 @@ def local_method(metaclass, args, unknown_args):
             #colorPrint.printERROR(shortTraceback(*sys.exc_info()))
         except (KeyboardInterrupt, EOFError):
             colorPrint.printERROR(_('Manually interrupted'))
+        except (GotErrorField,) as e:
+            pass
         except Exception as e:
             colorPrint.printERROR(shortTraceback(*sys.exc_info()))
             pass
@@ -482,7 +515,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
     view_obj.step = None
     view_obj.expert = True
     view_obj.brief = None
-    view_obj.onlyhelp = False
+    view_obj.onlyhelp = True
 
     try:
         view = getattr(metaObject, method_view_name)(0, view_obj)
@@ -525,7 +558,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
                 return None
 
             if method_result[0].type and method_result[0].type != "pid":
-                check_res = check_result_msg(method_result, view, check_res)
+                check_res = check_result_msg(method_result, view, check_res,args)
                 if not check_res:
                     return None
                 else:
@@ -575,8 +608,8 @@ def call_method(metaObject, args, unknown_args, colorPrint):
                 for field in Group.fields:
                     if field.name == ReturnedMessage.field:
                         params_text += getErrorOnParam(args,field)
-            colorPrint.printERROR('\r' + params_text + \
-                                     ReturnedMessage.message)
+            colorPrint.printERROR('\r' + params_text% \
+                                     str(ReturnedMessage.message))
             return None
     return method_result
 
@@ -772,3 +805,4 @@ def printTable(data, header=None):
     except Exception as e:
         print str(e)
         raise
+
