@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -138,9 +138,11 @@ class ClApplication(Application):
         try:
             com = certobj_cl.get_extension(certobj_cl.get_extension_count()-1)
             groups = com.get_data().split(':')[1]
-            groups_list = groups.split(',')
-        except:
+        except IndexError as e:
+            groups = ""
+        except Exception as e:
             return 0
+        groups_list = groups.split(',')
         cert_id = 0
         # open certificates database
         if not os.path.exists(certbase):
